# wxy_csv

#### 介绍
封装一些csv的操作方法

#### 软件架构
软件架构说明


#### 安装教程

1. twine
2. setuptools

#### 使用说明

1. pip安装     pip install wxy-Mail
2. pip卸载     pip uninstall wxy-Mail
3. pip升级     pip install --upgrade wxy-Mail
4. 调用        from wxy_Mail import Mail
